@@ -1,6 +1,6 @@
 #!/bin/sh
 #
-# Copyright (C) 2000, 2001, 2003, 2004, 2007, 2012, 2013, 2015, 2016  Internet Systems Consortium, Inc. ("ISC")
+# Copyright (C) 2000, 2001, 2003, 2004, 2007, 2012, 2013, 2015-2017  Internet Systems Consortium, Inc. ("ISC")
 #
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -29,7 +29,6 @@ Libraries:
 	isccc
 	isccfg
 	dns
-	lwres
 	bind9
 	irs
 EOF
@@ -65,7 +64,7 @@ while test $# -gt 0; do
 		echo_exec_prefix=true
 		;;
 	--version)
-		echo VERSION=9.11.2
+		echo VERSION=9.12.1
 		exit 0
 		;;
 	--cflags)
@@ -95,9 +94,6 @@ while test $# -gt 0; do
 		libdns=true;
 		libisc=true;
 		;;
-	lwres)
-		liblwres=true;
-		;;
 	bind9)
 		libdns=true;
 		libisc=true;
@@ -136,14 +132,11 @@ if test x"$echo_libs" = x"true"; then
 	if test x"$libirs" = x"true" ; then
 		libs="$libs -lirs"
 	fi
-	if test x"$liblwres" = x"true" ; then
-		libs="$libs -llwres"
-	fi
 	if test x"$libbind9" = x"true" ; then
 		libs="$libs -lbind9"
 	fi
 	if test x"$libdns" = x"true" ; then
-		libs="$libs -ldns  -lgssapi_krb5 -lkrb5 -lk5crypto -lcom_err -lcrypto"
+		libs="$libs -ldns  -lgssapi_krb5 -lkrb5 -lk5crypto -lcom_err"
 	fi
 	if test x"$libisccfg" = x"true" ; then
 		libs="$libs -lisccfg"
@@ -152,11 +145,11 @@ if test x"$echo_libs" = x"true"; then
 		libs="$libs -lisccc"
 	fi
 	if test x"$libisc" = x"true" ; then
-		libs="$libs -lisc"
+		libs="$libs -lisc  -lcrypto"
 		needothers=true
 	fi
 	if test x"$needothers" = x"true" ; then
-		libs="$libs  -ldl -lcap -ljson-c -lpthread -lm -lGeoIP  -L/usr/lib -lxml2 -lz -llzma -licui18n -licuuc -licudata -lm -ldl"
+		libs="$libs  -ldl -lcap -ljson-c -lpthread -lm -lGeoIP  -L/usr/lib -lxml2 -lz -llzma -licui18n -licuuc -licudata -lm -ldl "
 	fi
 	echo $libs
 fi
